==> osgeo-liblas-1.8.1_3.mojave.bottle.tar.gz: osgeo-liblas/1.8.1_3/lib/cmake/libLAS/liblas-depends-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "las" for configuration "Release"
set_property(TARGET las APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(las PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "@@HOMEBREW_PREFIX@@/lib/libtiff.dylib;@@HOMEBREW_PREFIX@@/lib/libgeotiff.dylib;@@HOMEBREW_CELLAR@@/osgeo-gdal/2.4.0/lib/libgdal.dylib;@@HOMEBREW_PREFIX@@/opt/osgeo-laszip@2/lib/liblaszip.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_program_options-mt.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_thread-mt.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_system-mt.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_iostreams-mt.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_filesystem-mt.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_chrono-mt.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_date_time-mt.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_atomic-mt.dylib;@@HOMEBREW_PREFIX@@/lib/libboost_regex-mt.dylib"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblas.2.4.0.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/liblas.3.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS las )
list(APPEND _IMPORT_CHECK_FILES_FOR_las "${_IMPORT_PREFIX}/lib/liblas.2.4.0.dylib" )

# Import target "las_c" for configuration "Release"
set_property(TARGET las_c APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(las_c PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "las"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblas_c.2.4.0.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/liblas_c.3.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS las_c )
list(APPEND _IMPORT_CHECK_FILES_FOR_las_c "${_IMPORT_PREFIX}/lib/liblas_c.2.4.0.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> osgeo-liblas-1.8.1_9.mojave.bottle.tar.gz: osgeo-liblas/1.8.1_9/lib/cmake/libLAS/liblas-depends-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "las" for configuration "Release"
set_property(TARGET las APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(las PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "@@HOMEBREW_PREFIX@@/lib/libtiff.dylib;@@HOMEBREW_PREFIX@@/lib/libgeotiff.dylib;@@HOMEBREW_CELLAR@@/osgeo-gdal/3.0.4_4/lib/libgdal.dylib;Boost::program_options;Boost::thread;Boost::system;Boost::iostreams;Boost::filesystem"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblas.2.4.0.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/liblas.3.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS las )
list(APPEND _IMPORT_CHECK_FILES_FOR_las "${_IMPORT_PREFIX}/lib/liblas.2.4.0.dylib" )

# Import target "las_c" for configuration "Release"
set_property(TARGET las_c APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(las_c PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "las"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblas_c.2.4.0.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/liblas_c.3.dylib"
  )

list(APPEND _IMPORT_CHECK_TARGETS las_c )
list(APPEND _IMPORT_CHECK_FILES_FOR_las_c "${_IMPORT_PREFIX}/lib/liblas_c.2.4.0.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
